==> nextcloud-30.0.10.tgz: nextcloud/apps/files_reminders/l10n/tr.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Dosya anımsatıcıları",
    "Reminder for {name}" : "{name} anımsatıcısı",
    "View file" : "Dosyayı görüntüle",
    "View folder" : "Klasörü görüntüle",
    "Set file reminders" : "Dosya anımsatıcıları ayarla",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Dosya anımsatıcıları**\n\nDosya anımsatıcıları ayarlayın.\n\nNot: `Dosya anımsatıcıları` uygulamasını kullanmak için `Bildirimler` uygulamasının kurulmuş ve etkinleştirilmiş olduğundan emin olun. `Bildirimler` uygulaması `Dosya anımsatıcıları` uygulamasının doğru çalışması için gerekli API uygulamalarını sağlar.",
    "Set reminder for \"{fileName}\"" : "\"{fileName}\" için anımsatıcı ayarla",
    "Set reminder at custom date & time" : "Özel bir tarih ve saat için anımsatıcı ayarla",
    "Clear reminder" : "Anımsatıcıyı temizle",
    "Please choose a valid date & time" : "Lütfen geçerli bir tarih ve saat seçin",
    "Reminder set for \"{fileName}\"" : "\"{fileName}\" için anımsatıcı ayarlandı",
    "Failed to set reminder" : "Anımsatıcı ayarlanamadı",
    "Reminder cleared for \"{fileName}\"" : "\"{fileName}\" anımsatıcısı kaldırıldı",
    "Failed to clear reminder" : "Anımsatıcı temizlenemedi",
    "We will remind you of this file" : "Size bu dosyayı anımsatacağız",
    "Cancel" : "İptal",
    "Set reminder" : "Anımsatıcı ayarla",
    "Reminder set" : "Anımsatıcı ayarlandı",
    "Set custom reminder" : "Özel anımsatıcı ayarla",
    "Later today" : "Bugün daha sonra",
    "Set reminder for later today" : "Bugün daha sonrası için anımsatıcı ayarla",
    "Tomorrow" : "Yarın",
    "Set reminder for tomorrow" : "Yarın için anımsatıcı ayarla",
    "This weekend" : "Bu hafta sonu",
    "Set reminder for this weekend" : "Bu hafta sonu için anımsatıcı ayarla",
    "Next week" : "Sonraki hafta",
    "Set reminder for next week" : "Gelecek hafta için anımsatıcı ayarla"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-30.0.12.tgz: nextcloud/apps/files_reminders/l10n/tr.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Dosya anımsatıcıları",
    "Reminder for {name}" : "{name} anımsatıcısı",
    "View file" : "Dosyayı görüntüle",
    "View folder" : "Klasörü görüntüle",
    "Files reminder" : "Dosyalar anımsatıcısı",
    "The \"files_reminders\" app can work properly." : "\"files_reminders\" uygulaması düzgün çalışabilir.",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "\"files_reminders\" uygulamasının düzgün çalışması için bildirim uygulaması gereklidir. Bildirimler uygulamasını etkinleştirin ya da files_reminder uygulamasını devre dışı bırakın.",
    "Set file reminders" : "Dosya anımsatıcıları ayarla",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Dosya anımsatıcıları**\n\nDosya anımsatıcıları ayarlayın.\n\nNot: `Dosya anımsatıcıları` uygulamasını kullanmak için `Bildirimler` uygulamasının kurulmuş ve etkinleştirilmiş olduğundan emin olun. `Bildirimler` uygulaması `Dosya anımsatıcıları` uygulamasının doğru çalışması için gerekli API uygulamalarını sağlar.",
    "Set reminder for \"{fileName}\"" : "\"{fileName}\" için anımsatıcı ayarla",
    "Set reminder at custom date & time" : "Özel bir tarih ve saat için anımsatıcı ayarla",
    "Clear reminder" : "Anımsatıcıyı temizle",
    "Please choose a valid date & time" : "Lütfen geçerli bir tarih ve saat seçin",
    "Reminder set for \"{fileName}\"" : "\"{fileName}\" için anımsatıcı ayarlandı",
    "Failed to set reminder" : "Anımsatıcı ayarlanamadı",
    "Reminder cleared for \"{fileName}\"" : "\"{fileName}\" anımsatıcısı kaldırıldı",
    "Failed to clear reminder" : "Anımsatıcı temizlenemedi",
    "We will remind you of this file" : "Size bu dosyayı anımsatacağız",
    "Cancel" : "İptal",
    "Set reminder" : "Anımsatıcı ayarla",
    "Reminder set" : "Anımsatıcı ayarlandı",
    "Set custom reminder" : "Özel anımsatıcı ayarla",
    "Later today" : "Bugün daha sonra",
    "Set reminder for later today" : "Bugün daha sonrası için anımsatıcı ayarla",
    "Tomorrow" : "Yarın",
    "Set reminder for tomorrow" : "Yarın için anımsatıcı ayarla",
    "This weekend" : "Bu hafta sonu",
    "Set reminder for this weekend" : "Bu hafta sonu için anımsatıcı ayarla",
    "Next week" : "Sonraki hafta",
    "Set reminder for next week" : "Gelecek hafta için anımsatıcı ayarla",
    "This files_reminder can work properly." : "Bu files_reminder düzgün çalışabilir.",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "files_reminders uygulamasının düzgün çalışması için bildirim uygulaması gereklidir. Bildirimler uygulamasını etkinleştirin ya da files_reminder uygulamasını devre dışı bırakın."
},
"nplurals=2; plural=(n > 1);");
